function outl=pccont3(p,A,k,inc,h)

% PCCONT3     Kernel Density estimate p% contour plot for tri-variate data.
%
%             Example: S1=randn(50,3);
%                      S2=6+randn(50,3);
%                      S=[S1;S2];
%                      outl=pccont3(75,S,'knorm',48);
%
%             PCCONT3(P,A,K,INC,H) displays a surface which encloses P% 
%             of the data.  Groups are formed by ranking the data by 
%             kernel density estimate.
%
%             The rows of A contain the whole data-set.
% 
%             The kernel is given by the function in K.
%             'KMVN' is the multivariate normal distribution.
%
%             INC controls the granularity of the mesh.
%
%             The optional parameter H represents the window width.
%             If omitted, an 'optimal' value is used.
%
%             Christian C. Beardah 1996

g=inc;

if nargin==4,
  h=0;
end;

w=zeros(length(p),2);

x=A(:,1);
y=A(:,2);
z=A(:,3);

p=100-p;

[n d]=size(A);

xrange=max(x)-min(x);
yrange=max(y)-min(y);
zrange=max(z)-min(z);

xa=linspace(min(x)-xrange/20,max(x)+xrange/20,g);
ya=linspace(min(y)-yrange/20,max(y)+yrange/20,g);
za=linspace(min(z)-zrange/20,max(z)+zrange/20,g);

[X,Y,Z]=meshgrid(xa,ya,za);

f=kdest3d(X,Y,Z,A,k,h);

% slice(X,Y,Z,f,mean(xa),mean(ya),mean(za),g);
% xlabel('x values');
% ylabel('y values');
% zlabel('z values');

r=kdest3d(x,y,z,A,k,h);

[order index]=sort(r);

m=ceil(n*p/100);

for i=1:length(p),
  if m(i)==0,
    v(i)=0.9*order(1); 
  end;

  if m(i)>0 & m(i)<n,
    v(i)=(order(m(i))+order(m(i)+1))/2;
  end;

  if m(i)==n,
    v(i)=(order(n-1)+order(n))/2;
  end;

end;

f=(f>v);
[i,j]=find(f);
for k=1:length(i),
  hpt(k,:)=[X(i(k),j(k)) Y(i(k),j(k)) Z(i(k),j(k))];
end;

% figure;
% plot3(x(index(m+1:n)),y(index(m+1:n)),z(index(m+1:n)),'yx');
% hold on;
% plot3(x(index(1:m)),y(index(1:m)),z(index(1:m)),'ro');
% for l=1:m,
%   text(x(index(l)),y(index(l)),z(index(l)),int2str(index(l)));
% end;
% xlabel('x values');
% ylabel('y values');
% zlabel('z values');

plot3(hpt(:,1),hpt(:,2),hpt(:,3),'y.');
hold on;
plot3(x(index(m+1:n)),y(index(m+1:n)),z(index(m+1:n)),'gx');
plot3(x(index(1:m)),y(index(1:m)),z(index(1:m)),'ro');
xlabel('x values');
ylabel('y values');
zlabel('z values');

for k=1:m,
  vec=ones(length(i),1)*A(index(k),:)-hpt;
  for l=1:length(i),
    nvec(l)=norm(vec(l,:));
  end;
  mvec(k,1)=min(nvec);
end;

outl=[index(1:m), x(index(1:m)), y(index(1:m)), z(index(1:m)), r(index(1:m)), mvec];

% figure;
% x=1:m;
% [y,z]=sort(outl(:,6));
% plot(x,y,'wx');
% xlabel('Outlier number (ranked)');
% ylabel('Minimum Distance from contour');
% hold on;
% for l=1:m,
%   text(x(l),y(l),int2str(outl(z(l),1)));
% end;

% figure;
% plot(outl(:,6),outl(:,5),'wx');
% xlabel('Minimum Distance from contour');
% ylabel('Density');
% hold on;
% for l=1:m,
%   text(outl(l,6),outl(l,5),int2str(outl(l,1)));
% end;

hold off;